==> isis-1.16.2-source-release.zip: isis-1.16.2/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/objectvalue/labelat/LabelAtFacetAbstract.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.isis.core.metamodel.facets.objectvalue.labelat;

import org.apache.isis.applib.annotation.LabelPosition;
import org.apache.isis.core.metamodel.facetapi.Facet;
import org.apache.isis.core.metamodel.facetapi.FacetHolder;
import org.apache.isis.core.metamodel.facets.MultipleValueFacetAbstract;

public abstract class LabelAtFacetAbstract extends MultipleValueFacetAbstract implements LabelAtFacet {

    public static Class<? extends Facet> type() {
        return LabelAtFacet.class;
    }

    private final LabelPosition value;

    public LabelAtFacetAbstract(final LabelPosition value, final FacetHolder holder) {
        super(type(), holder);
        this.value = value;
    }

    @Override
    public LabelPosition label() {
        return value;
    }

    @Override
    protected String toStringValues() {
        return "position=" + value;
    }

}

==> isis-1.17.0-source-release.zip: isis-1.17.0/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/objectvalue/labelat/LabelAtFacetAbstract.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.isis.core.metamodel.facets.objectvalue.labelat;

import java.util.Map;

import org.apache.isis.applib.annotation.LabelPosition;
import org.apache.isis.core.metamodel.facetapi.Facet;
import org.apache.isis.core.metamodel.facetapi.FacetHolder;
import org.apache.isis.core.metamodel.facets.MultipleValueFacetAbstract;

public abstract class LabelAtFacetAbstract extends MultipleValueFacetAbstract implements LabelAtFacet {

    public static Class<? extends Facet> type() {
        return LabelAtFacet.class;
    }

    private final LabelPosition value;

    public LabelAtFacetAbstract(final LabelPosition value, final FacetHolder holder) {
        super(type(), holder);
        this.value = value;
    }

    @Override
    public LabelPosition label() {
        return value;
    }

    @Override
    protected String toStringValues() {
        return "position=" + value;
    }

    @Override public void appendAttributesTo(final Map<String, Object> attributeMap) {
        super.appendAttributesTo(attributeMap);
        attributeMap.put("label", value);
    }
}
